@@ -1,15 +1,15 @@
-require(ICEinfer)
+library(ICEinfer)
 # input the fluoxpin data of Sacristan et al. (2000).
 data(fluoxpin)
 # Effectiveness = respond, Cost = cost, trtm = flxpin where
-# flxpin = 1 ==> fluoxetine plus pindolol and flxpin = 0 ==> fluoxetine alone
+# flxpin = 1 ==> fluoxetine plus pindolol and flxpin = 0 ==> fluoxetine plus placebo
 
 cat("\n Display of Lambda => Shadow Price Summary Statistics...\n")
 ICEscale(fluoxpin, flxpin, respond, cost)
 ICEscale(fluoxpin, flxpin, respond, cost, lambda=100000)
 
-cat("\nBootstrap ICE Uncertainty calculations can be lengthy...\n")
-fpunc <<- ICEuncrt(fluoxpin, flxpin, respond, cost, R = 10000, lambda=100000)
+cat("\nBootstrap ICE Uncertainty calculations with R=25000 can be lengthy...\n")
+fpunc <<- ICEuncrt(fluoxpin, flxpin, respond, cost, lambda=100000, R=5000)
 fpunc
 
 cat("\nDisplay the Bootstrap ICE Uncertainty Distribution...\n")
